/*
This dofile generates teh alternative dependent variable table.
*/

************
* Preliminaries
************

set more off
clear all
est clear
program drop _all

local root = [REDACTED]
local instruments d_pernum d_persf d_lghwy				
local compvars rm_es rm_f hhe hhf						

use `root'/data/master.dta, replace

capt prog drop firstf								
prog firstf, eclass
eret post A B
eret scalar N = el(C,1,1)
eret scalar N_clust = el(D,1,1)
eret scalar r2 = el(E,1,1)
eret scalar J = el(F,1,1)
eret scalar Jp = el(G,1,1)
eret scalar FF = el(H,1,4)
eret scalar FFp = el(H,1,7)
end

************
* Variables of Interest
************

gen frac_nonprod = [REDACTED]
gen labstruck = labor/exp(struck)
gen labequipk = labor/exp(equipk)
gen labk = labor/(exp(struck) + exp(equipk))
gen equipkstruck = exp(equipk - struck)


local boxvars fracbus frac_nonprod labk equipkstruck

************
* Estimation
************

foreach lhs in `boxvars'{
	foreach model in `compvars'{
		qui ivregress gmm `lhs' yr* (d_`model' = `instruments'), cluster(cea) robust
		mat A = e(b)									
		mat B = e(V)
		mat C = e(N)
		mat D = e(N_clust)
		mat E = e(r2)
		qui estat overid
		mat F = r(HansenJ)
		mat G = r(p_HansenJ)
		qui estat first
		mat H = r(singleresults)
		firstf
		estadd scalar Nround = round(e(N),100)
		estadd scalar Cround = round(e(N_clust),50)
		eststo iv_`lhs'_`model'

}

estout iv* using [REDACTED], replace cells(b(fmt(%9.4f)) se(par fmt(%9.4f))) stats(Nround Cround r2 FF FFp J Jp, fmt(%9.0f %9.0f %9.4f %9.4f %9.4f %9.4f) label("Observations (rounded)" "Clusters (rounded)" "R2" " First-Stage F" "p Value" "Hausman J Statistic" "p Value") ) drop(_cons yr*) coll(,none) numbers style(tab)



