/*
This dofile generates the alternative specifications and robustness table
*/


************
* Preliminaries
************

set more off
clear all
est clear
program drop _all

local maindir = [REDACTED]
local instruments d_pernum d_persf d_lghwy			
local lag_instruments dl_pernum dl_persf dl_lghwy	
local compvars rm_es rm_f hhe hhf			

use [REDACTED], replace

capt prog drop modmergemodels				
prog modmergemodels, eclass
syntax namelist
tempname b V N tmp
foreach name of local namelist{
	qui est restore `name'
	mat `b' = nullmat(`b'), e(b)
	mat `tmp' = e(V)
	capt confirm matrix `V'
	if _rc {
		mat `V' = `tmp'
	}
	else {
	mat `V' = ( `V' , J(rowsof(`V'),colsof(`tmp'),0) \ J(rowsof(`tmp'), colsof(`V'),0), `tmp' )
	mat `N' = nullmat(`N'), e(N)
	}
}
local names: colfullnames `b'
mat coln `V' = `names'
mat rown `V' = `names'
eret post `b' `V'
eret scalar N = el(`N',1,1)
end


replace rm_es = exp(rm_es)				
xtset id year						

************
* Estimation
************

foreach model in `compvars'{
eststo lag_`model' : qui ivregress gmm tfpq yr* (d_`model' = `lag_instruments'), cluster(cea)				
eststo min_`model' : qui ivregress gmm tfpq yr* (d_`model' = `instruments') if rm_es >= 10, cluster(cea)	
eststo area_`model' : qui ivregress gmm tfpq yr* area (d_`model' = `instruments'), cluster(cea)				
eststo two_`model' : qui ivreg2 tfpq yr* (d_`model' = `instruments'), cluster(cea year) partial(yr*)		
eststo fe_`model' : qui xtivreg tfpq yr* (d_`model' = `instruments'), fe			
eststo tfpr_`model' : qui ivregress gmm tfpr yr* (d_`model' = `instruments'), cluster(cea)			
}

collapse (mean) tfpq d_rm_es d_rm_f d_hhe d_hhf d_co_em d_lghwy d_pernum d_persf d_per5f cea yr*, by(id)
foreach model in `compvars'{
eststo bw_`model' : qui ivregress gmm tfpq yr* (d_`model' = `instruments'), cluster(cea)			
}

foreach robust in lag min area fe bw tfpr{
mergemodels `robust'_rm_es `robust'_rm_f `robust'_hhe `robust'_hhf			
eststo merged_`robust'												
}
modmergemodels two_rm_es two_rm_f two_hhe two_hhf	
eststo merged_`tqo'

estout merged_* using [REDACTED], replace cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) stats(N, fmt(%9.0f)) label coll(,none) mlabel(,none) numbers drop(yr* o.* area) style(fixed)
