/*
This dofile generates decomposition tables.
*/

************
* Assembly
************

set more off
clear all
program drop _all

capt prog drop bclean		
prog bclean, eclass
syntax anything(name=A)
eret post `A'
end

local maindir = [REDACTED]
local instruments d_pernum d_lghwy		
local compvars rm_es rm_f hhe hhf			

use [REDACTED], replace


************
* Static Decomposition
************

replace pqs = exp(pqs)						

bysort cea year: egen avg_tfpq = mean(tfpq)					
bysort cea year : egen totq = sum(pqs)					
gen share = pqs/totq							
bysort cea year: egen weightedprod = sum(tfpq*share)		
bysort cea year: egen num_es = count(id)					
bysort cea year: egen cross_q = sum((tfpq - avg_tfpq)*(share - num_es^(-1)))	

************
* Reduced-form results
************

foreach model in `compvars'{
	eststo wprod_`model' : qui ivreg weightedprod yr* (d_`model' = `instruments'), cluster(cea)
	eststo aqprod_`model' : qui ivreg tfpq yr* (d_`model' = `instruments'), cluster(cea)
	eststo cprod_`model' : qui ivreg cross_q yr* (d_`model' = `instruments'), cluster(cea)
}

estout wprod* using [REDACTED], replace cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) stats(N r2, fmt(%9.0f %9.4f)) drop(_cons yr*) coll(,none) mlabel(,none) numbers style(fixed)
estout aqprod* using [REDACTED], replace cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) stats(N r2, fmt(%9.0f %9.4f)) drop(_cons yr*) coll(,none) mlabel(,none) numbers style(fixed)
estout cprod* using [REDACTED], replace cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) stats(N r2, fmt(%9.0f %9.4f)) drop(_cons yr*) coll(,none) mlabel(,none) numbers style(fixed)

sum weightedprod if year==82		
replace weightedprod = 1 + weightedprod - r(mean)	
replace tfpq = 1 + tfpq - r(mean)		

foreach var in weightedprod tfpq cross_q{
	sum `var' if year == 82				
	mat tmp = r(mean),r(sd)				
	mat coln tmp = `var' `var'_sd			
	mat b_82 = nullmat(b_82),tmp		
}
bclean b_82					
eststo decomp_82			

foreach yr in 87 92{
	foreach var in weightedprod tfpq cross_q wdif t1 t2 t3 t4 t5{
		qui sum `var' if year == `yr'	
		mat tmp = r(mean), r(sd)	
		mat coln tmp = `var' `var'_sd		
		mat b_`yr' = nullmat(b_`yr'),tmp	
	}
	bclean b_`yr'				
	eststo decomp_`yr'			
}


estout decomp_* using [REDACTED], replace cells(b(fmt(%9.4f))) coll(,none) style(fixed)






