
% This function runs the monte carlo simulation and spits out betas, confidence interval lengths, coverage dummies, and p values for the F test on the joint significance of the correction terms. 

function [b1, ci1, b2, ci2, cov1, cov2, p] =  montecarlo_onerun(lam_estab, lam_area, groups, prodstd, s) 

% Here Im going to let the area and the number of firms be exponentially distributed with parameters lam_area and lam_establ. Note that I always add a minimum of one firm to each market.

rng(90210 + s) ;

area = exprnd(lam_area,groups,1) ;
marketsize = 1 + floor(exprnd(lam_estab,groups,1));

% Now constructing the data at the group level.

for m = 1:groups
   comp = log(marketsize./area) ;
   prod = sort(normrnd(0,prodstd,marketsize(m),1)) ;
   loc = transpose([1:marketsize(m)])/marketsize(m) ;
   for q = 1:9
       quantiles(m,q) = min(prod(loc>=q/10));
   end
end

% Next, run the regressions and generate the relevant statistics. 

for q = 1:9
    X = [ones(groups,1),comp] ;
    Xc = [ones(groups,1),comp,marketsize,marketsize.^2,marketsize.^3,marketsize.^4,marketsize.^5] ;
    Y = quantiles(:,q) ;
    
    beta(:,q) = inv(transpose(X)*X)*transpose(X)*Y ;
    resid = Y - X*beta(:,q) ;
    se(:,q) = sqrt(diag((groups - 1)^(-1)*transpose(resid)*resid*inv(transpose(X)*X))) ;
    
    [b,s,ssr1] = ols(Y,X) ;
    b = b(2) ;
    s = s(2) ;
    b1(q) = b ;
    ci1(q) = 3.92*s ;
    cov1(q) = [(b - 1.96*s<0).*(b + 1.96*s>0)] ;

    [b,s,ssr2] = ols(Y,Xc) ;
    b = b(2) ;
    s = s(2) ;
    b2(q) = b ;
    ci2(q) = 3.92*s ;
    cov2(q) = [(b - 1.96*s<0).*(b + 1.96*s>0)] ;

    fval = ((ssr1 - ssr2)/3)/(ssr2/(groups - 5 - 1)) ;
    p(q) = 1-fcdf(fval,3,groups - 5 - 1) ;

end

end
