/*
* This code runs the analysis for the MOPS extension
*/

clear
set more off
estimates clear

capt prog drop firstf					
prog firstf, eclass
eret post A B
eret scalar N = el(C,1,1)
eret scalar r2 = el(D,1,1)
eret scalar N_clust = el(E,1,1)
eret scalar J = el(F,1,1)
eret scalar Jp = el(G,1,1)
eret scalar FF = el(H,1,4)
eret scalar FFp = el(H,1,7)
end

***************
* Macro Definition
***************
{
local maindir = [REDACTED]
local compvars rm_es rm_f
local instruments d_pernum d_lghwy
}

***************
* Importing Data
***************

use [REDACTED]

***************
* Estimation
***************


foreach model in `compvars'{
  foreach lhs in management monitoring incentives {

      qui ivregress gmm bs_`lhs' (d_`model' = `instruments') if yr==2010, cluster(cea) robust
      mat A = e(b)									
      mat B = e(V)
      mat C = e(N)
      mat D = e(r2)
      mat E = e(N_clust)
      qui estat overid
      mat F = r(HansenJ)
      mat G = r(p_HansenJ)
      qui estat first
      mat H = r(singleresults)
      firstf
      estadd scalar Nround = round(e(N),100)
      estadd scalar Cround = round(e(N_clust),50)
      eststo reg_`lhs'_`model'

  }
}



estout reg_* using [REDACTED], replace cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) stats(Nround Cround r2 FF FFp J Jp, fmt(%9.0f %9.0f %9.4f %9.4f %9.4f %9.4f) label("Observations (rounded)" "Clusters (rounded)" "R^2" " First-Stage F" "p Value" "Hausman J Statistic" "p Value") ) label coll(,none) drop(_cons) numbers style(tab)


