/*
This dofile generates the OLS and IV tables 
*/


************
* Preliminaries
************

set more off
clear all
est clear
program drop _all

local maindir = [REDACTED]
local instruments d_pernum d_lghwy						
local compvars rm_es rm_f hhe hhf					


capt prog drop firstf						
prog firstf, eclass
eret post A B
eret scalar N = el(C,1,1)
eret scalar r2 = el(D,1,1)
eret scalar J = el(E,1,1)
eret scalar Jp = el(F,1,1)
eret scalar FF = el(G,1,4)
eret scalar FFp = el(G,1,7)
end

use [REDACTED], replace

************
* Estimation
************

foreach model in `compvars'{
eststo ols_`model' : qui reg tfpq d_`model' yr*, cluster(cea)	
qui ivregress gmm tfpq yr* (d_`model' = `instruments'), cluster(cea) 	
mat A = e(b)		
mat B = e(V)
mat C = e(N)
mat D = e(r2)
qui estat overid
mat E = r(HansenJ)
mat F = r(p_HansenJ)
qui estat first
mat G = r(singleresults)
firstf
eststo iv_`model'
}

estout ols* iv* using [REDACTED], replace cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) stats(N r2 FF FFp J Jp, fmt(%9.0f %9.4f %9.4f %9.4f %9.4f) label("Observations" "$ R^2 $ " " First-Stage F" "p Value" "Hausman J Statistic" "p Value") ) drop(_cons yr*) coll(,none) mlabel(,none) numbers style(tex)

sort cea year
by cea year: egen avg_tfpq = mean(tfpq)				
by cea year : egen totq = sum(pqs)				
gen share = pqs/totq							
by cea year: egen mean_share = mean(share)
gen share_prod = (share/mean_share)*tfpq 

foreach model in `compvars'{
eststo tilde_`model': qui ivregress gmm share_prod yr* (d_`model' = `instruments'), cluster(cea) 	
}
esttab tilde_*, drop(yr*) se stats(N r2 FF FFp J Jp)
