/*
This dofile generates the Quantiles Tables
*/


************
* Preliminaries
************

set more off
clear all
est clear
program drop _all

local maindir = [REDACTED]
local instruments d_pernum d_persf d_lghwy
local compvars rm_es rm_f hhe hhf


capt prog drop pclean				
prog pclean, eclass
syntax anything(name=A)
mat coln `A' = rm_es rm_f hhe hhf
eret post `A'
end

capt prog drop mergemodels			
prog mergemodels, eclass
syntax namelist
tempname b V N tmp
foreach name of local namelist{
	qui est restore `name'
	mat `b' = nullmat(`b'), e(b)
	mat `b' = `b'[1,1..colsof(`b')-1]
	mat `tmp' = e(V)
	mat `tmp' = `tmp'[1..rowsof(`tmp')-1,1..colsof(`tmp')-1]
	capt confirm matrix `V'
	if _rc {
		mat `V' = `tmp'
	}
	else {
	mat `V' = ( `V' , J(rowsof(`V'),colsof(`tmp'),0) \ J(rowsof(`tmp'), colsof(`V'),0), `tmp' )
	mat `N' = nullmat(`N'), e(N)
	}
}
local names: colfullnames `b'
mat coln `V' = `names'
mat rown `V' = `names'
eret post `b' `V'
eret scalar N = el(`N',1,1)
end

use [REDACTED], replace

************
* Estimation
************

collapse (max) yr* rm_es d_rm_es d_rm_f d_hhe d_hhf `instruments' (p10) q10 = tfpq (p20) q20 = tfpq (p30) q30 = tfpq (p40) q40 = tfpq (p50) q50 = tfpq (p60) q60 = tfpq (p70) q70 = tfpq (p80) q80 = tfpq (p90) q90 = tfpq, by(cea year)			// This line generates the CEA-level quantiles of the tfpq distibution and collapses everything to that level

replace rm_es = exp(rm_es)  		
gen rm_es_sqr = rm_es^2			
gen rm_es_cub = rm_es^3			

foreach quant in 10 20 30 40 50 60 70 80 90{
	ren rm_es n_`quant'_1		/
	ren rm_es_sqr n_`quant'_2
	ren rm_es_cub n_`quant'_3

	foreach model in `compvars' {
		eststo quant_`model'_`quant' : qui ivregress gmm q`quant' yr* n_`quant'_* (d_`model' = `instruments'), cluster(cea) 	
		qui test (n_`quant'_1 = 0) (n_`quant'_2 = 0) (n_`quant'_3 = 0)							
		mat pm_`quant' = nullmat(pm_`quant'), r(p)									
	}
	ren n_`quant'_1 rm_es		
	ren n_`quant'_2 rm_es_sqr
	ren n_`quant'_3 rm_es_cub
	pclean pm_`quant'														
	eststo p_`quant'													
	local list_`quant' quant_rm_es_`quant' quant_rm_f_`quant' quant_hhe_`quant' quant_hhf_`quant'					
	mergemodels `list_`quant''											
	eststo qm_`quant'													

}

estout qm* using [REDACTED], replace cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) stats(N, fmt(%9.0f)) coll(,none) mlabel(,none) numbers drop(yr* n* o.*) style(fixed)
estout p* using [REDACTED], replace cells(b(fmt(%9.4f))) coll(,none) mlabel(,none) numbers style(fixed)
