/*
This dofile runs the second order markov process version of the selection correction. 
*/

************
* Preliminaries
************

set more off
clear all
est clear
program drop _all

local maindir = [REDACTED]
local compvars rm_es rm_f hhe hhf

log using [REDACTED], replace text 

capt prog drop estclean
prog estclean, eclass
syntax anything(name=model)
tempname b V Nround Cround J Jp temp
local names bc `model' bp20 bp02 bp11 bp10 bp01 bds
qui estat overid
mat `b' = e(b)
mat `V' = e(V)
mat coleq `b' = ""
mat coleq `V' = ""
mat roweq `V' = ""
mat coln `b' = `names'
mat coln `V' = `names'
mat rown `V' = `names'
mat `Nround' = e(Nround)
mat `Cround' = e(Cround)
mat `J' = r(J)
mat `Jp' = r(J_p)
eret post `b' `V'
eret scalar Nround = el(`Nround',1,1)
eret scalar Cround = el(`Cround',1,1)
eret scalar J = el(`J',1,1)
eret scalar Jp = el(`Jp',1,1)
end

[REDACTED], replace

keep id year tfpq d_pernum d_rm_es d_rm_f d_hhe d_hhf d_persf d_lghwy cea
reshape wide tfpq d_pernum d_rm_es d_rm_f d_hhe d_hhf d_persf d_lghwy cea, i(id) j(year)
rename cea92 cea
drop cea8*

drop if tfpq82 == . | tfpq87 == . | tfpq92 == .

************
* Estimation
************

local rescale 100

foreach model in `compvars' {

	local sn10 (tfpq82 - {bs}*d_`model'82)
	local sn01 (tfpq87 - {bs}*d_`model'87)
	local sn30 `sn10'^3
	local sn21 `sn10'^2*`sn01'^1
	local sn12 `sn10'^1*`sn01'^2
	local sn03 `sn01'^3
	local sn20 `sn10'^2
	local sn02 `sn01'^2
	local sn11 `sn10'^1*`sn01'^1

	local n1_series {bp10}*`sn10' + {bp01}*`sn01'
	local n2_series {bp20}*`sn20' + {bp02}*`sn02' + {bp11}*`sn11'
	local n3_series {bp30}*`sn30' + {bp03}*`sn03' + {bp21}*`sn21' + {bp12}*`sn12'
	local eps1 (tfpq92 - {bc} - {bs}*d_`model'92 - (`n2_series' + `n1_series'))
	local eps2 (tfpq92 - {bc} - {bs}*d_`model'92 - {bds}*d_`model'92)
	
	local inst_82 d_pernum82 d_persf82 d_lghwy82 
	local inst_87 d_pernum87 d_persf87 d_lghwy87
	local inst_92 d_pernum92 d_persf92 d_lghwy92

	eststo `model': gmm (`rescale'*`eps1') (`rescale'*`eps2')  (`rescale'*`eps1'*`sn10') (`rescale'*`eps1'*`sn01') (`rescale'*`eps1'*`sn20') (`rescale'*`eps1'*`sn02') (`rescale'*`eps1'*`sn11') , instruments(1: `inst_82') instruments(2: `inst_82' `inst_87' `inst_92') winitial(identity) vce(cluster cea)  wmatrix(cluster cea) technique(dfp) from(bc -2 bs .05 bds 0 bp20 0 bp02 0 bp11 0 bp01 0 bp10 0)
	estadd scalar Nround = round(e(N),100)
	estadd scalar Cround = round(e(N_clust),50)
	estimates save [REDACTED], replace
	disp("check1")
	estclean `model'
	disp("check2")
	eststo m2_`model'
	disp("check3")
}


estout m2_* using [REDACTED], replace cells(b(fmt(%9.4f)) se(par fmt(%9.4f))) stats(Nround Cround J Jp, fmt(%9.0f %9.0f %9.4f %9.4f)) label coll(,none) numbers keep(`compvars' bds) style(tab)

log close

