/*
This dofile generates esimates for the selection correction approach
*/

************
* Preliminaries
************

set more off
clear all
est clear
program drop _all

local maindir = [REDACTED]
local compvars rm_es rm_f hhe hhf

capt prog drop estclean
prog estclean, eclass
syntax anything(name=model)
tempname b V N J Jp temp
local names b0 by1 `model' bp3 by2 bp2 bp1 b1 by3 bds
qui estat overid
mat `b' = e(b)
mat `V' = e(V)
mat coleq `b' = ""
mat coleq `V' = ""
mat roweq `V' = ""
mat coln `b' = `names'
mat coln `V' = `names'
mat rown `V' = `names'
mat `N' = e(N)
mat `J' = r(J)
mat `Jp' = r(J_p)
eret post `b' `V'
eret scalar N = el(`N',1,1)
eret scalar J = el(`J',1,1)
eret scalar Jp = el(`Jp',1,1)
end

use [REDACTED], replace



************
* Estimation
************

foreach model in `compvars' {

	local sn3 (L5.tfpq - {b0} - {by2}*yr87 - {bs}*L5.d_`model')^3
	local sn2 (L5.tfpq - {b0} - {by2}*yr87 - {bs}*L5.d_`model')^2
	local sn1 (L5.tfpq - {b0} - {by2}*yr87 - {bs}*L5.d_`model')^1
	
	local n_series {bp3}*`sn3' + {bp2}*`sn2' + {bp1}*`sn1'
	local eps1 (tfpq - {b0} - {by1}*yr92 - {bs}*d_`model' - (`n_series'))
	local eps2 (tfpq - {bs}*d_`model' - {b1} - {by3}*yr92 - {bds}*d_`model')
	local inst_l yr92 dl_pernum dl_persf dl_lghwy
	local inst_c yr92 d_pernum d_persf d_lghwy

	gmm `eps1' `eps2' (`eps1'*`sn3') (`eps1'*`sn2') (`eps1'* `sn1'), instruments(1:`inst_l') instruments(2:`inst_c') vce(cluster cea) winitial(identity) wmatrix(cluster cea) technique(dfp)
	estimates save [REDACTED], replace
	disp("check1")
	estclean `model'
	disp("check2")
	eststo correct_final_`model'
	disp("check3")
}


estout correct_final* using [REDACTED], replace cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) stats(N J Jp, fmt(%9.0f %9.4f %9.4f)) label coll(,none) mlabel(,none) numbers keep(`compvars' bds) style(fixed)


